@@ -1,3 +1,6 @@
+from math import cos, sin, tan, acos, atan, atan2, pi
+sqrt = lambda x: x**0.5
+"""
 def cartesian_to_servo(self, leg_number, posX, posY, posZ): # Leg numbers go from left to right, front to back (leg 0 is front left and leg 6 is back right). Positions are given in relation to the coxa servo of each leg
 	self._coxaFeetDist = sqrt(posX**2 + posY**2)
 	self._IKSW = sqrt((self._coxaFeetDist - self._coxaLength)**2 + posZ**2)
@@ -26,4 +29,5 @@ def cartesian_to_servo(self, leg_number, posX, posY, posZ): # Leg numbers go fro
 		if self._reversed_servos[index]==True:
 			angle = 180-angle
 	angles = [int(i+90) for i in angles]
-	return angles
\ No newline at end of file
+	return angles
+"""
